#'  Variable Group Response indicator Recalculation
#'
#' Recalculates the response indicators matrix (rij) for a variable group  resulting from function \code{\link[sdap]{vargroup}}. If a response is found in one element of the variable group, the whole variable group is considered to have a response (1).
#' @author Beat Hulliger, Juan Berdugo
#' @param data (mandatory) A dataframe containing the data to be processed.
#' @param rij (mandatory) A matrix created using the function \code{\link[sdap]{rind}}.
#' @param varj (mandatory) A vector containing the variable numbers that belong to the response group. This vector can be calculated using the function (\code{\link[sdap]{vargroup}}).
#' @return A matrix of the type rij with recalculated response indicators for the variables in the varj vector.
#' @export

rgroup<-function(data,rij,varj)
{
  if (missing(rij))
  {
    cat("Response indicator matrix rij is missing\n")
    return()
  }
  p <- length(varj)
  # check whether there is at least one reponse in the group
  rg <- 1-apply(1-rij[,varj],1,prod)
  rij[,varj] <- matrix(rep(rg,each=p),ncol=p,byrow=T)
  return(rij)
}
