#'  Response Indicator
#'
#' The response indicator function tests a dataframe vs a list of missingness indicators. The output is a matrix "rij" the same size of the dataframe containing values 1 or 0 indicating whether there is a response (1) or not (0).
#' @author Beat Hulliger, Juan Berdugo
#' @param data (mandatory) A dataframe containing the data to be processed.
#' @param miss.ind (optional): A vector with the missing indicators to be considered. When the argument is missing, the function considers an empty string and NA as missingness indicators. Special codes like -99 can be defined here.
#' @return A matrix "rij" containing response indicators for each variable and observation.
#' @export

rind <- function(data, miss.ind="")
  # 3.7.2015, 23.8.2015
  # Beat Hulliger
  # Individual item response indicator
  # data is the data frame
{
  rij <- !is.na(data)
  # to avoid checking with NA remove NA from miss.ind
  if (sum(is.na(miss.ind))>0) miss.ind <- miss.ind[-which(is.na(miss.ind))]
  for (k in miss.ind)
  {
    rijk <- data==k # response is k
    rijk[is.na(rijk)] <- FALSE # in case of NA set rijk to FALSE
    rij[rijk] <- FALSE   # where response is k set rij to FALSE
  }
  nana <- sum(is.na(rij))  # check whether all rij are defined
  if (nana>0) cat(paste("Number of missing values in rij: ", nana,"/n"))
  # convert to dummy
  storage.mode(rij) <- "integer"
  return(rij)
}
